summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/video/k007420.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/video/k007420.cpp')
-rw-r--r--src/mame/video/k007420.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/video/k007420.cpp b/src/mame/video/k007420.cpp
index ae702212c26..db5a1052cc5 100644
--- a/src/mame/video/k007420.cpp
+++ b/src/mame/video/k007420.cpp
@@ -250,11 +250,11 @@ void k007420_device::sprites_draw( bitmap_ind16 &bitmap, const rectangle &clipre
}
//-------------------------------------------------
// static_set_palette_tag: Set the tag of the
// palette device
//-------------------------------------------------
-void k007420_device::static_set_palette_tag(device_t &device, const char *tag)
+void k007420_device::set_palette_tag(const char *tag)
{
- downcast<k007420_device &>(device).m_palette.set_tag(tag);
+ m_palette.set_tag(tag);
}
@@ -250,11 +250,11 @@ void k007420_device::sprites_draw( bitmap_ind16 &bitmap, const rectangle &clipre
}
//-------------------------------------------------
-// static_set_palette_tag: Set the tag of the
+// set_palette_tag: Set the tag of the
// palette device
//-------------------------------------------------